define(
//begin v1.x content
({
	widgetLabel: "Correcció ortogràfica per lots",
	unfound: "No trobat",
	skip: "Salta",
	skipAll: "Salta tot",
	toDic: "Afegeix al diccionari",
	suggestions: "Suggeriments",
	replace: "Substitueix",
	replaceWith: "Substitueix per",
	replaceAll: "Substitueix tot",
	cancel: "Cancel·la",
	msg: "No s'ha trobat cap error ortogràfic",
	iSkip: "Saltar aquest",
	iSkipAll: "Saltar tots els que són com aquest",
	iMsg: "No hi ha suggeriments ortogràfics"
})

//end v1.x content
);
